==> morioh-1.0.1.tgz: package/README.md <==
# Morioh Theme: Responsive Template with Bootstrap 4, HTML5 and Vue.js

[![Morioh Responsive Template with Bootstrap 4, HTML5 and Vue.js](https://i.imgur.com/gWYKl5F.png)](https://morioh.com/www/morioh/)

[![Morioh Responsive Template with Bootstrap 4, HTML5 and Vue.js](https://i.imgur.com/tHs60Xu.png)](https://morioh.com/www/morioh/)


### Preview and Guide

☞ [Morioh Html5 Preview](https://morioh.com/www/morioh/)


### Quick start
Looking to quickly add Morioh to your project? Use CDN, provided for free by the folks at UNPKG.

```
<link rel="stylesheet" href="https://unpkg.org/morioh/dist/css/morioh.min.css">
```
```js
<script src="https://unpkg.com/jquery@3.4.1/dist/jquery.slim.min.js"></script>
<script src="https://unpkg.com/popper.js@1.16.0/dist/umd/popper.min.js"></script>
<script src="https://unpkg.com/bootstrap@4.4.1/dist/js/bootstrap.min.js"></script>
```

### NPM

```js
npm install morioh
```

### Yarn

```js
yarn install morioh
```

### Starter template
Be sure to have your pages set up with the latest design and development standards. That means using an HTML5 doctype and including a viewport meta tag for proper responsive behaviors. Put it all together and your pages should look like this:

```
<!doctype html>
<html lang="en">
    <head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <!-- Morioh CSS -->
    <link rel="stylesheet" href="https://unpkg.org/morioh/dist/css/morioh.min.css">

    <title>Hello, world!</title>
    </head>
    <body>
    <h1>Hello, world!</h1>

    <!-- Optional JavaScript -->
    <!-- jQuery first, then Popper.js, then Bootstrap JS -->
    <script src="https://unpkg.com/jquery@3.4.1/dist/jquery.slim.min.js"></script>
    <script src="https://unpkg.com/popper.js@1.16.0/dist/umd/popper.min.js"></script>
    <script src="https://unpkg.com/bootstrap@4.4.1/dist/js/bootstrap.min.js"></script>
    </body>
</html>
```

### Community
Stay up to date on the development of Morioh and reach out to the community with these helpful resources.
Follow [@codek_tv](https://twitter.com/codek_tv) and [@im_a_developer](https://twitter.com/im_a_developer) on Twitter.
Join the official [Discord](https://discord.gg/sqxU6un) room: [https://discord.gg/sqxU6un](https://discord.gg/sqxU6un).

==> morioh-1.0.5.tgz: package/README.md <==
# Morioh Theme: Responsive Template with Bootstrap 4, HTML5 and Vue.js

[![Morioh Responsive Template with Bootstrap 4, HTML5 and Vue.js](https://i.imgur.com/gWYKl5F.png)](https://morioh.com/www/morioh/)

[![Morioh Responsive Template with Bootstrap 4, HTML5 and Vue.js](https://i.imgur.com/tHs60Xu.png)](https://morioh.com/www/morioh/)


### Preview and Guide

☞ [Morioh Html5 Preview](https://morioh.com/www/morioh/)


### Quick start
Looking to quickly add Morioh to your project? Use CDN, provided for free by the folks at UNPKG.

```html
<link rel="stylesheet" href="https://unpkg.com/morioh/dist/css/morioh.min.css">
```
OR

```html
<link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/morioh/dist/css/morioh.min.css">
```

```html
<script src="https://unpkg.com/jquery@3.4.1/dist/jquery.slim.min.js"></script>
<script src="https://unpkg.com/popper.js@1.16.0/dist/umd/popper.min.js"></script>
<script src="https://unpkg.com/bootstrap@4.4.1/dist/js/bootstrap.min.js"></script>
```

### NPM

```
npm install morioh
```

### Yarn

```
yarn install morioh
```

### Starter template
Be sure to have your pages set up with the latest design and development standards. That means using an HTML5 doctype and including a viewport meta tag for proper responsive behaviors. Put it all together and your pages should look like this:

```html
<!doctype html>
<html lang="en">
    <head>
    <!-- Required meta tags -->
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <!-- Morioh CSS -->
    <link rel="stylesheet" href="https://unpkg.com/morioh/dist/css/morioh.min.css">

    <title>Hello, world!</title>
    </head>
    <body>
    <h1>Hello, world!</h1>

    <!-- Optional JavaScript -->
    <!-- jQuery first, then Popper.js, then Bootstrap JS -->
    <script src="https://unpkg.com/jquery@3.4.1/dist/jquery.slim.min.js"></script>
    <script src="https://unpkg.com/popper.js@1.16.0/dist/umd/popper.min.js"></script>
    <script src="https://unpkg.com/bootstrap@4.4.1/dist/js/bootstrap.min.js"></script>
    </body>
</html>
```

### Community
Stay up to date on the development of Morioh and reach out to the community with these helpful resources.

Follow [@codek_tv](https://twitter.com/codek_tv) and [@im_a_developer](https://twitter.com/im_a_developer) on Twitter.

Join the official [Discord](https://discord.gg/sqxU6un) room: [https://discord.gg/sqxU6un](https://discord.gg/sqxU6un).
